pub struct Attribute {
pub id: Option<u8>,
pub name: Option<String>,
pub format: String,
pub byte_order: String,
pub drivetype: Option<Type>,
}Expand description
SMART attribute description
Fields
id: Option<u8>id of described attribute
name: Option<String>attribute name
format: Stringvalue format, like raw48 or tempminmax
byte_order: Stringbytes of attribute data to make value of (usually something like r543210, where r, v, w represent reserved byte, current and worst values respectively)
drivetype: Option<Type>what kind of device this description is applicable to: HDD, SSD, or both